/*******************************************************************************
 * Copyright 2018 fmCreation
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they
 * will be approved by the European Commission - subsequent
 * versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the
 * Licence.
 * You may obtain a copy of the Licence at:
 *
 *    https://progs.frankmuenster.de/eupl_v1-2_en/
 *
 * Unless required by applicable law or agreed to in
 * writing, software distributed under the Licence is
 * distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied.
 * See the Licence for the specific language governing
 * permissions and limitations under the Licence.
 ******************************************************************************/

package de.frankmuenster.jameica.depot.finanzen.boerseffm;

import org.apache.commons.lang.StringUtils;

/**
 * Mapper f&uuml;r dei URL eines InstrumentTyps.
 *
 * @author Frank Mnster
 *
 */
public enum InstrumentTypeEnum {

    /**
     * Typ Aktie
     */
    AKTIEN("Aktien", "aktien"), //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Typ Anleihe
     */
    ANLEIHEN("Anleihen", "anleihen"), //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Typ ETF/ETP
     */
    ETF_ETP("ETF/ETP", "etp"), //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Typ Index
     */
    INDIZES("Indizes", "index"), //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Typ Fond
     */
    FONDS("Fonds", "fonds"), //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Typ Rohstoffe
     */
    ROHSTOFFE("Rohstoffe", "rohstoffe"), //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Typ W&aumlhrung
     */
    WAEHRUNG("Whrung", "devisen"), //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Typ Zertifikat
     */
    ZERTIFIKATE("Zertifikate", "zertifikate"); //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Der Name des Instrumenttyps
     */
    private String name;

    /**
     * Der Name in der URL
     */
    private String url;

    /**
     * Liefert InstrumentTyp zu einem Namen
     * 
     * @param typeName
     *            der InstrumentTypName
     * 
     * @return den InstrumentTyp oder NULL, wenn der InstrumentTypName nicht
     *         bekannt ist.
     */
    public static InstrumentTypeEnum getInstrumentType(final String typeName) {

	InstrumentTypeEnum type = null;
	if (StringUtils.trimToNull(typeName) != null) {
	    for (final InstrumentTypeEnum instrument : InstrumentTypeEnum.values()) {
		if (instrument.getName().equals(typeName)) {
		    type = instrument;
		    break;
		}
	    }
	}
	return type;
    }

    /**
     * Liefert die URL eines InstrumentTypNames.
     * 
     * @param typeName
     *            InstrumentTypName
     * 
     * @return die URL oder NULL, wenn der InstrumentTypName nicht bekannt ist.
     */
    public static String getUrl(final String typeName) {

	String url = null;
	if (StringUtils.trimToNull(typeName) != null) {
	    for (final InstrumentTypeEnum instrument : InstrumentTypeEnum.values()) {
		if (instrument.getName().equals(typeName)) {
		    url = instrument.getUrl();
		    break;
		}
	    }
	}
	return url;
    }

    private InstrumentTypeEnum(final String name, final String url) {
	this.name = name;
	this.url = url;
    }

    /**
     * Liefert den InstrumentTypNamen
     * 
     * @return den InstrumentTypNamen
     */
    public String getName() {
	return this.name;
    }

    /**
     * Liefert die URL
     * 
     * @return die URL
     */
    public String getUrl() {
	return this.url;
    }

}
