/*******************************************************************************
 * Copyright 2018 fmCreation
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they
 * will be approved by the European Commission - subsequent
 * versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the
 * Licence.
 * You may obtain a copy of the Licence at:
 *
 *    https://progs.frankmuenster.de/eupl_v1-2_en/
 *
 * Unless required by applicable law or agreed to in
 * writing, software distributed under the Licence is
 * distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied.
 * See the Licence for the specific language governing
 * permissions and limitations under the Licence.
 ******************************************************************************/

package de.frankmuenster.jameica.depot.finanzen.currate;

/**
 * CurRate service error
 *
 * @author Frank Mnster
 */
public enum CurRateServiceErrors {

    /**
     * Operation not supported
     */
    OPERATION_NOT_SUPPORTED(100),

    /**
     * Date parameter missing or wrong
     */
    PARAM_DATE(101),

    /**
     * Currency parameter missing or wrong
     */
    PARAM_CURRENCY(102),

    /**
     * Currency is not supported
     */
    CURRENCY_NOT_SUPPORTED(103),

    /**
     * No rate found for the given date.
     */
    NO_RATE_FOR_DATE(104),

    /**
     * The date is before 4th of January 1999
     */
    DATE_TOO_OLD(105),

    /**
     * The SQL query failed
     */
    SQL_QUERY_FAILED(201),

    /**
     * The service cannot connect to the database
     */
    DB_NOT_CONNECTED(200);

    /**
     * The error code
     */
    private int errorCode;

    /**
     * Returns the CurRateServiceErrors for the given code, or null of code is
     * supported.
     *
     * @param code
     * @return the CurRateServiceErrors
     */
    public static CurRateServiceErrors getError(final int code) {

	CurRateServiceErrors serviceError = null;

	for (final CurRateServiceErrors error : CurRateServiceErrors.values()) {
	    if (error.getErrorCode() == code) {
		serviceError = error;
		break;
	    }
	}

	return serviceError;

    }

    private CurRateServiceErrors(final int errorCode) {
	this.errorCode = errorCode;

    }

    /**
     * Returns the error code
     *
     * @return the error code
     */
    public int getErrorCode() {

	return this.errorCode;
    }

}
