/*******************************************************************************
 * Copyright 2018 fmCreation
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they
 * will be approved by the European Commission - subsequent
 * versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the
 * Licence.
 * You may obtain a copy of the Licence at:
 *
 *    https://progs.frankmuenster.de/eupl_v1-2_en/
 *
 * Unless required by applicable law or agreed to in
 * writing, software distributed under the Licence is
 * distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied.
 * See the Licence for the specific language governing
 * permissions and limitations under the Licence.
 ******************************************************************************/

package de.frankmuenster.jameica.depot.gui.utils;

import java.util.Random;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;

import de.willuhn.jameica.gui.GUI;

/**
 * Utility Klasse fr Farben
 *
 * @author Frank Mnster
 */
public final class ColorUtils {

    /**
     * Erzeugt eine zuf&auml;llige Farbe
     * 
     * @return eine zuf&auml;llig erzeugt Farbe
     */
    public static Color getRandomColor() {

	final Random random = new Random();
	int red = random.nextInt(512);
	int green = random.nextInt(512);
	int blue = random.nextInt(512);

	final Color mix = GUI.getDisplay().getSystemColor(SWT.COLOR_RED);

	// mix the color
	if (mix != null) {
	    red = (red + mix.getRed()) / 3;
	    green = (green + mix.getGreen()) / 3;
	    blue = (blue + mix.getBlue()) / 3;
	}

	return new Color(GUI.getDisplay(), red, green, blue);
    }

    /**
     * Erstellt eine AWT Farbe basierend auf den RGB-Werten einer SWT Farbe.
     * 
     * @param color
     *            Die SWT Farbe.
     * @return ein AWT Farbobjekt.
     */
    public static java.awt.Color toAwtColor(final Color color) {
	return new java.awt.Color(color.getRed(), color.getGreen(), color.getBlue());
    }

    /**
     * Standardkonstruktor
     */
    private ColorUtils() {
	// absichlich leer
    }

}
