/*******************************************************************************
 * Copyright 2018 fmCreation
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they
 * will be approved by the European Commission - subsequent
 * versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the
 * Licence.
 * You may obtain a copy of the Licence at:
 *
 *    https://progs.frankmuenster.de/eupl_v1-2_en/
 *
 * Unless required by applicable law or agreed to in
 * writing, software distributed under the Licence is
 * distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied.
 * See the Licence for the specific language governing
 * permissions and limitations under the Licence.
 ******************************************************************************/

package de.frankmuenster.jameica.depot.kursanalyse.mom;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;

import de.frankmuenster.jameica.depot.kursanalyse.dialog.AbstractAddAnalyseDialog;
import de.frankmuenster.jameica.depot.utils.I18N;
import de.willuhn.jameica.gui.Action;
import de.willuhn.jameica.gui.dialogs.AbstractDialog;
import de.willuhn.jameica.gui.input.IntegerInput;
import de.willuhn.jameica.gui.parts.ButtonArea;
import de.willuhn.jameica.gui.util.Container;
import de.willuhn.jameica.gui.util.SimpleContainer;
import de.willuhn.util.ApplicationException;

/**
 * Momentum AddDialog
 *
 * @author Frank Mnster
 */
public class MomentumAddDialog extends AbstractAddAnalyseDialog<Integer> {

    /**
     * Standardwert
     */
    private transient int result = 14;

    /**
     * Erzeugt einen neuen AddDialog
     */
    public MomentumAddDialog() {
	super(AbstractDialog.POSITION_CENTER, false);
	this.setTitle(I18N.tr("MomentumAddDialog.dialogTitle")); //$NON-NLS-1$
    }

    /**
     * de.willuhn.jameica.gui.dialogs.AbstractDialog.getData()
     */
    @Override
    protected Integer getData() {

	return this.result;
    }

    /**
     * @see de.willuhn.jameica.gui.dialogs.AbstractDialog#paint(Composite
     *      parent)
     */
    @Override
    protected void paint(final Composite parent) {

	final GridLayout layout = new GridLayout();
	layout.numColumns = 1;
	parent.setLayout(layout);

	// Erstelle einfachen Container
	final Container container = new SimpleContainer(parent, true, 2);

	final IntegerInput period = new IntegerInput();
	period.setHint(Integer.toString(this.result));
	period.setName(I18N.tr("MomentumAddDialog.periodName")); //$NON-NLS-1$
	period.setComment(I18N.tr("MomentumAddDialog.periodComment", Integer.toString(this.result)));//$NON-NLS-1$
	container.addLabelPair(I18N.tr("MomentumAddDialog.lblPeriod"), period); //$NON-NLS-1$
	container.addText(" ", false); //$NON-NLS-1$

	final ButtonArea buttons = new ButtonArea();
	buttons.addButton(I18N.tr("_btnAdd"), //$NON-NLS-1$
		new Action() {

		    /**
		     * @see de.willuhn.jameica.gui.Action#handleAction(Object
		     *      context)
		     */
		    @Override
		    public void handleAction(final Object context) throws ApplicationException {

			if (period.getValue() == null) {
			    MomentumAddDialog.this.result = 14;
			} else {
			    MomentumAddDialog.this.result = (Integer) period.getValue();
			}
			MomentumAddDialog.this.close();
		    }
		}, null, true, "ok.png"); //$NON-NLS-1$

	buttons.addButton(I18N.tr("_cancelBtn"), new Action() { //$NON-NLS-1$

	    /**
	     * @see de.willuhn.jameica.gui.Action#handleAction(Object context)
	     */
	    @Override
	    public void handleAction(final Object context) throws ApplicationException {

		MomentumAddDialog.this.result = 0;
		MomentumAddDialog.this.close();
	    }
	}, null, false, "window-close.png"); //$NON-NLS-1$

	container.addButtonArea(buttons);

	setSize(SWT.DEFAULT, 160);

    }

}
