/*******************************************************************************
 * Copyright 2018 fmCreation
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they
 * will be approved by the European Commission - subsequent
 * versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the
 * Licence.
 * You may obtain a copy of the Licence at:
 *
 *    https://progs.frankmuenster.de/eupl_v1-2_en/
 *
 * Unless required by applicable law or agreed to in
 * writing, software distributed under the Licence is
 * distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied.
 * See the Licence for the specific language governing
 * permissions and limitations under the Licence.
 ******************************************************************************/
package de.frankmuenster.jameica.depot.wertpapierorder;

import java.util.Date;

/**
 * Implementierung einer Order-Bean
 *
 * @author Frank Mnster
 */
@SuppressWarnings("PMD.LongVariable")
public class OrderImpl implements Order {

    /**
     * Das Symbol
     */
    private String symbol;

    /**
     * Der name des WP
     */
    private String name;

    /**
     * Das Order Datum
     */
    private Date orderDate;

    /**
     * Das Order Volumen
     */
    private double orderVolume;

    /**
     * Der Order-Preis
     */
    private double orderPrice;

    /**
     * Der Order-Preis in der Hauptw&auml;hrung
     */
    private double orderPriceInMainCurrency;

    /**
     * Die zus&auml;tzlichen Kosten
     */
    private double additionalCosts;

    /**
     * Die W&auml;hrung derzus&auml;tzlichen Kosten
     */
    private String additionalCostsCurrency;

    /**
     * Die zus&auml;tzlichen Kosten in der haupw&auml;hrung
     */
    private double additionalCostsInMainCurrency;

    /**
     * Kommantar
     */
    private String comment;

    /**
     * Standardkonstruktor
     */
    public OrderImpl() {
        // Absichlich leer
    }

    /**
     * @see Order#getSymbol()
     */
    @Override
    public String getSymbol() {

        return this.symbol;
    }

    /**
     * @see Order#setSymbol(String)
     */
    @Override
    public void setSymbol(final String symbol) {

        this.symbol = symbol;
    }

    /**
     * @see Order#getName()
     */
    @Override
    public String getName() {

        return this.name;
    }

    /**
     * @see Order#setName(String)
     */
    @Override
    public void setName(final String name) {

        this.name = name;
    }

    /**
     * @see Order#getOrderDate()
     */
    @Override
    public Date getOrderDate() {

        return this.orderDate;
    }

    /**
     * @see Order#setOrderDate(Date)
     */
    @Override
    public void setOrderDate(final Date orderDate) {

        this.orderDate = orderDate;
    }

    /**
     * @see Order#getOrderVolume()
     */
    @Override
    public double getOrderVolume() {

        return this.orderVolume;
    }

    /**
     * @see Order#setOrderVolume(double)
     */
    @Override
    public void setOrderVolume(final double orderVolume) {

        this.orderVolume = orderVolume;
    }

    /**
     * @see Order#getOrderPrice()
     */
    @Override
    public double getOrderPrice() {

        return this.orderPrice;
    }

    /**
     * @see Order#setOrderPrice(double)
     */
    @Override
    public void setOrderPrice(final double orderPrice) {

        this.orderPrice = orderPrice;
    }

    /**
     * @see Order#getOrderPriceInMainCurrency()
     */
    @Override
    public double getOrderPriceInMainCurrency() {

        return this.orderPriceInMainCurrency;
    }

    /**
     * @see Order#setOrderPriceInMainCurrency(double)
     */
    @Override
    public void setOrderPriceInMainCurrency(final double orderPriceInMainCurrency) {

        this.orderPriceInMainCurrency = orderPriceInMainCurrency;
    }

    /**
     * @see Order#getAdditionalCosts()
     */
    @Override
    public double getAdditionalCosts() {

        return this.additionalCosts;
    }

    /**
     * @see Order#setAdditionalCosts(double)
     */
    @Override
    public void setAdditionalCosts(final double additionalCosts) {

        this.additionalCosts = additionalCosts;
    }

    /**
     * @see Order#getAdditionalCostsInMainCurrency()
     */
    @Override
    public double getAdditionalCostsInMainCurrency() {

        return this.additionalCostsInMainCurrency;
    }

    /**
     * @see Order#setAdditionalCostsInMainCurrency(double)
     */
    @Override
    public void setAdditionalCostsInMainCurrency(final double additionalCostsInMainCurrency) {

        this.additionalCostsInMainCurrency = additionalCostsInMainCurrency;
    }

    /**
     * @see Order#getAdditionalCostsCurrency()
     */
    @Override
    public String getAdditionalCostsCurrency() {

        return this.additionalCostsCurrency;
    }

    /**
     * @see Order#setAdditionalCostsCurrency(String)
     */
    @Override
    public void setAdditionalCostsCurrency(final String additionalCostsCurrency) {

        this.additionalCostsCurrency = additionalCostsCurrency;
    }

    /**
     * @see Order#getComment()
     */
    @Override
    public String getComment() {

        return this.comment;
    }

    /**
     * @see Order#setComment(String)
     */
    @Override
    public void setComment(final String comment) {

        this.comment = comment;
    }

    /**
     * @see Order#getOrderPriceTotal()
     */
    @Override
    public double getOrderPriceTotal() {

        return this.getOrderVolume() * this.getOrderPrice();
    }

    /**
     * @see Order#setOrderPriceTotal(double)
     */
    @Override
    public void setOrderPriceTotal(final double orderPriceTotal) {

        // TODO: Mal schauen
    }
}
